@@ -23,10 +23,12 @@ LaplaceApproximation <- function(Model=NULL, parm=NULL, Data=NULL,
           parm <- rep(0, length(Data$parm.names))}
      for (i in 1:length(Data)) {
           if(is.matrix(Data[[i]])) {
-               mat.rank <- qr(Data[[i]], tol=1e-10)$rank
-               if(mat.rank < ncol(Data[[i]])) {
-                    cat("WARNING: Matrix", names(Data)[[i]],
-                         "may be rank-deficient.\n")}}}
+               if(!any(is.na(Data[[i]])) & !any(is.nan(Data[[i]])) &
+                    !any(is.infinite(Data[[i]]))) {
+                    mat.rank <- qr(Data[[i]], tol=1e-10)$rank
+                    if(mat.rank < ncol(Data[[i]])) {
+                         cat("WARNING: Matrix", names(Data)[[i]],
+                              "may be rank-deficient.\n")}}}}
      if({Interval <= 0} | {Interval > 1}) Interval <- 1.0E-6
      Iterations <- round(Iterations)
      if(Iterations < 10) {Iterations <- 10}
