@@ -15,11 +15,11 @@ joint.density.plot <- function(x, y, Title=NULL, contour=TRUE, color=FALSE)
      x <- as.vector(x)
      y <- as.vector(y)
      if(length(y) != length(x))
-          stop("vectors x and y must be the same length in contour.plot().")
+          stop("vectors x and y must be the same length in joint.density.plot().")
      if(any(!is.finite(x)))
-          stop("x has missing or infinite values in contour.plot().")
+          stop("x has missing or infinite values in joint.density.plot().")
      if(any(!is.finite(y)))
-          stop("y has missing or infinite values in contour.plot().")
+          stop("y has missing or infinite values in joint.density.plot().")
      ### Two-Dimensional Kernel Density Estimates
      kde2d <- function(x, y, h, n=25, lims=c(range(x), range(y)))
           {
