@@ -20,11 +20,10 @@ invlogit <- function(x)
      InvLogit <- 1 / {1 + exp(-x)}
      return(InvLogit)
      }
-
 logit <- function(p)
      {
      p <- as.vector(p)
-     if({p < 0} | {p > 1}) {
+     if ({any(p < 0)} | {any(p > 1)}) {
           stop("p is not in the interval [0,1] in logit().")}
      Logit <- log(p / {1 - p})
      return(Logit)
